<?php
namespace Aws\PinpointEmail\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Pinpoint Email Service** service.
 */
class PinpointEmailException extends AwsException {}
