<?php
namespace Aws\ComputeOptimizerAutomation\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Compute Optimizer Automation** service.
 */
class ComputeOptimizerAutomationException extends AwsException {}
