<?php
namespace Aws\InspectorScan;

use Aws\AwsClient;

/**
 * This client is used to interact with the **Inspector Scan** service.
 * @method \Aws\Result scanSbom(array $args = [])
 * @method \GuzzleHttp\Promise\Promise scanSbomAsync(array $args = [])
 */
class InspectorScanClient extends AwsClient {}
