<?php
namespace Aws\ApplicationSignals\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon CloudWatch Application Signals** service.
 */
class ApplicationSignalsException extends AwsException {}
