<?php
namespace Aws\ChimeSDKIdentity\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Chime SDK Identity** service.
 */
class ChimeSDKIdentityException extends AwsException {}
