<?php
namespace Aws\SignerData;

use Aws\AwsClient;

/**
 * This client is used to interact with the **AWS Signer Data Plane** service.
 * @method \Aws\Result getRevocationStatus(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getRevocationStatusAsync(array $args = [])
 */
class SignerDataClient extends AwsClient {}
