<?php

declare(strict_types=1);

namespace Pest\Arch\Objects;

use PHPUnit\Architecture\Elements\ObjectDescriptionBase as BaseObjectDescriptionBase;

/**
 * @internal
 */
final class ObjectDescriptionBase extends BaseObjectDescriptionBase
{
    //
}
