<?php
// This file was auto-generated from sdk-root/src/data/accessanalyzer/2019-11-01/waiters-2.json
return [ 'version' => 2, 'waiters' => [ 'PolicyPreviewConfigurationActive' => [ 'delay' => 5, 'maxAttempts' => 24, 'operation' => 'GetPolicyPreviewConfiguration', 'acceptors' => [ [ 'matcher' => 'pathAll', 'argument' => 'policyPreviewConfigurations[].status', 'state' => 'success', 'expected' => 'ACTIVE', ], [ 'matcher' => 'pathAny', 'argument' => 'policyPreviewConfigurations[].status', 'state' => 'failure', 'expected' => 'FAILED', ], ], ], 'PolicyPreviewJobCompleted' => [ 'delay' => 30, 'maxAttempts' => 5, 'operation' => 'GetPolicyPreviewJob', 'acceptors' => [ [ 'matcher' => 'path', 'argument' => 'jobDetails.jobStatus', 'state' => 'success', 'expected' => 'COMPLETED', ], [ 'matcher' => 'path', 'argument' => 'jobDetails.jobStatus', 'state' => 'failure', 'expected' => 'FAILED', ], [ 'matcher' => 'path', 'argument' => 'jobDetails.jobStatus', 'state' => 'failure', 'expected' => 'CANCELED', ], ], ], ],];
