<?php
namespace Aws\SimpleDBv2\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon SimpleDB v2** service.
 */
class SimpleDBv2Exception extends AwsException {}
