<?php
namespace Aws\CognitoIdentityProvider\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Cognito Identity Provider** service.
 */
class CognitoIdentityProviderException extends AwsException {}
