<?php
namespace Aws\LicenseManager\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS License Manager** service.
 */
class LicenseManagerException extends AwsException {}
