<?php
namespace Aws\CodeCommit\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS CodeCommit** service.
 */
class CodeCommitException extends AwsException {}
