<?php
// This file was auto-generated from sdk-root/src/data/backupsearch/2018-05-10/paginators-1.json
return [ 'pagination' => [ 'ListSearchJobBackups' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'Results', ], 'ListSearchJobResults' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'Results', ], 'ListSearchJobs' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'SearchJobs', ], 'ListSearchResultExportJobs' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'ExportJobs', ], ],];
