<?php
namespace Aws\GreengrassV2\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS IoT Greengrass V2** service.
 */
class GreengrassV2Exception extends AwsException {}
