<?php
namespace Aws\InspectorScan\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Inspector Scan** service.
 */
class InspectorScanException extends AwsException {}
