<?php
namespace Aws\RedshiftServerless\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Redshift Serverless** service.
 */
class RedshiftServerlessException extends AwsException {}
