<?php
namespace Aws\AppIntegrationsService\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon AppIntegrations Service** service.
 */
class AppIntegrationsServiceException extends AwsException {}
