<?php
namespace Aws\NovaAct\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Nova Act Service** service.
 */
class NovaActException extends AwsException {}
