<?php
namespace Aws\PartnerCentralBenefits\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Partner Central Benefits API** service.
 */
class PartnerCentralBenefitsException extends AwsException {}
