<?php
namespace Aws\CloudWatch\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the Amazon CloudWatch service.
 */
class CloudWatchException extends AwsException {}
