<?php
namespace Aws\Bedrock;

use Aws\AwsClient;

/**
 * This client is used to interact with the **Amazon Bedrock** service.
 * @method \Aws\Result batchDeleteEvaluationJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchDeleteEvaluationJobAsync(array $args = [])
 * @method \Aws\Result cancelAutomatedReasoningPolicyBuildWorkflow(array $args = [])
 * @method \GuzzleHttp\Promise\Promise cancelAutomatedReasoningPolicyBuildWorkflowAsync(array $args = [])
 * @method \Aws\Result createAutomatedReasoningPolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createAutomatedReasoningPolicyAsync(array $args = [])
 * @method \Aws\Result createAutomatedReasoningPolicyTestCase(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createAutomatedReasoningPolicyTestCaseAsync(array $args = [])
 * @method \Aws\Result createAutomatedReasoningPolicyVersion(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createAutomatedReasoningPolicyVersionAsync(array $args = [])
 * @method \Aws\Result createCustomModel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createCustomModelAsync(array $args = [])
 * @method \Aws\Result createCustomModelDeployment(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createCustomModelDeploymentAsync(array $args = [])
 * @method \Aws\Result createEvaluationJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createEvaluationJobAsync(array $args = [])
 * @method \Aws\Result createFoundationModelAgreement(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createFoundationModelAgreementAsync(array $args = [])
 * @method \Aws\Result createGuardrail(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createGuardrailAsync(array $args = [])
 * @method \Aws\Result createGuardrailVersion(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createGuardrailVersionAsync(array $args = [])
 * @method \Aws\Result createInferenceProfile(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createInferenceProfileAsync(array $args = [])
 * @method \Aws\Result createMarketplaceModelEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createMarketplaceModelEndpointAsync(array $args = [])
 * @method \Aws\Result createModelCopyJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createModelCopyJobAsync(array $args = [])
 * @method \Aws\Result createModelCustomizationJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createModelCustomizationJobAsync(array $args = [])
 * @method \Aws\Result createModelImportJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createModelImportJobAsync(array $args = [])
 * @method \Aws\Result createModelInvocationJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createModelInvocationJobAsync(array $args = [])
 * @method \Aws\Result createPromptRouter(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createPromptRouterAsync(array $args = [])
 * @method \Aws\Result createProvisionedModelThroughput(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createProvisionedModelThroughputAsync(array $args = [])
 * @method \Aws\Result deleteAutomatedReasoningPolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteAutomatedReasoningPolicyAsync(array $args = [])
 * @method \Aws\Result deleteAutomatedReasoningPolicyBuildWorkflow(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteAutomatedReasoningPolicyBuildWorkflowAsync(array $args = [])
 * @method \Aws\Result deleteAutomatedReasoningPolicyTestCase(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteAutomatedReasoningPolicyTestCaseAsync(array $args = [])
 * @method \Aws\Result deleteCustomModel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteCustomModelAsync(array $args = [])
 * @method \Aws\Result deleteCustomModelDeployment(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteCustomModelDeploymentAsync(array $args = [])
 * @method \Aws\Result deleteEnforcedGuardrailConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteEnforcedGuardrailConfigurationAsync(array $args = [])
 * @method \Aws\Result deleteFoundationModelAgreement(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteFoundationModelAgreementAsync(array $args = [])
 * @method \Aws\Result deleteGuardrail(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteGuardrailAsync(array $args = [])
 * @method \Aws\Result deleteImportedModel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteImportedModelAsync(array $args = [])
 * @method \Aws\Result deleteInferenceProfile(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteInferenceProfileAsync(array $args = [])
 * @method \Aws\Result deleteMarketplaceModelEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteMarketplaceModelEndpointAsync(array $args = [])
 * @method \Aws\Result deleteModelInvocationLoggingConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteModelInvocationLoggingConfigurationAsync(array $args = [])
 * @method \Aws\Result deletePromptRouter(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deletePromptRouterAsync(array $args = [])
 * @method \Aws\Result deleteProvisionedModelThroughput(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteProvisionedModelThroughputAsync(array $args = [])
 * @method \Aws\Result deleteResourcePolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteResourcePolicyAsync(array $args = [])
 * @method \Aws\Result deregisterMarketplaceModelEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deregisterMarketplaceModelEndpointAsync(array $args = [])
 * @method \Aws\Result exportAutomatedReasoningPolicyVersion(array $args = [])
 * @method \GuzzleHttp\Promise\Promise exportAutomatedReasoningPolicyVersionAsync(array $args = [])
 * @method \Aws\Result getAutomatedReasoningPolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getAutomatedReasoningPolicyAsync(array $args = [])
 * @method \Aws\Result getAutomatedReasoningPolicyAnnotations(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getAutomatedReasoningPolicyAnnotationsAsync(array $args = [])
 * @method \Aws\Result getAutomatedReasoningPolicyBuildWorkflow(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getAutomatedReasoningPolicyBuildWorkflowAsync(array $args = [])
 * @method \Aws\Result getAutomatedReasoningPolicyBuildWorkflowResultAssets(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getAutomatedReasoningPolicyBuildWorkflowResultAssetsAsync(array $args = [])
 * @method \Aws\Result getAutomatedReasoningPolicyNextScenario(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getAutomatedReasoningPolicyNextScenarioAsync(array $args = [])
 * @method \Aws\Result getAutomatedReasoningPolicyTestCase(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getAutomatedReasoningPolicyTestCaseAsync(array $args = [])
 * @method \Aws\Result getAutomatedReasoningPolicyTestResult(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getAutomatedReasoningPolicyTestResultAsync(array $args = [])
 * @method \Aws\Result getCustomModel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getCustomModelAsync(array $args = [])
 * @method \Aws\Result getCustomModelDeployment(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getCustomModelDeploymentAsync(array $args = [])
 * @method \Aws\Result getEvaluationJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getEvaluationJobAsync(array $args = [])
 * @method \Aws\Result getFoundationModel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getFoundationModelAsync(array $args = [])
 * @method \Aws\Result getFoundationModelAvailability(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getFoundationModelAvailabilityAsync(array $args = [])
 * @method \Aws\Result getGuardrail(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getGuardrailAsync(array $args = [])
 * @method \Aws\Result getImportedModel(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getImportedModelAsync(array $args = [])
 * @method \Aws\Result getInferenceProfile(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getInferenceProfileAsync(array $args = [])
 * @method \Aws\Result getMarketplaceModelEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getMarketplaceModelEndpointAsync(array $args = [])
 * @method \Aws\Result getModelCopyJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getModelCopyJobAsync(array $args = [])
 * @method \Aws\Result getModelCustomizationJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getModelCustomizationJobAsync(array $args = [])
 * @method \Aws\Result getModelImportJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getModelImportJobAsync(array $args = [])
 * @method \Aws\Result getModelInvocationJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getModelInvocationJobAsync(array $args = [])
 * @method \Aws\Result getModelInvocationLoggingConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getModelInvocationLoggingConfigurationAsync(array $args = [])
 * @method \Aws\Result getPromptRouter(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getPromptRouterAsync(array $args = [])
 * @method \Aws\Result getProvisionedModelThroughput(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getProvisionedModelThroughputAsync(array $args = [])
 * @method \Aws\Result getResourcePolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getResourcePolicyAsync(array $args = [])
 * @method \Aws\Result getUseCaseForModelAccess(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getUseCaseForModelAccessAsync(array $args = [])
 * @method \Aws\Result listAutomatedReasoningPolicies(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listAutomatedReasoningPoliciesAsync(array $args = [])
 * @method \Aws\Result listAutomatedReasoningPolicyBuildWorkflows(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listAutomatedReasoningPolicyBuildWorkflowsAsync(array $args = [])
 * @method \Aws\Result listAutomatedReasoningPolicyTestCases(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listAutomatedReasoningPolicyTestCasesAsync(array $args = [])
 * @method \Aws\Result listAutomatedReasoningPolicyTestResults(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listAutomatedReasoningPolicyTestResultsAsync(array $args = [])
 * @method \Aws\Result listCustomModelDeployments(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listCustomModelDeploymentsAsync(array $args = [])
 * @method \Aws\Result listCustomModels(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listCustomModelsAsync(array $args = [])
 * @method \Aws\Result listEnforcedGuardrailsConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listEnforcedGuardrailsConfigurationAsync(array $args = [])
 * @method \Aws\Result listEvaluationJobs(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listEvaluationJobsAsync(array $args = [])
 * @method \Aws\Result listFoundationModelAgreementOffers(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listFoundationModelAgreementOffersAsync(array $args = [])
 * @method \Aws\Result listFoundationModels(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listFoundationModelsAsync(array $args = [])
 * @method \Aws\Result listGuardrails(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listGuardrailsAsync(array $args = [])
 * @method \Aws\Result listImportedModels(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listImportedModelsAsync(array $args = [])
 * @method \Aws\Result listInferenceProfiles(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listInferenceProfilesAsync(array $args = [])
 * @method \Aws\Result listMarketplaceModelEndpoints(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listMarketplaceModelEndpointsAsync(array $args = [])
 * @method \Aws\Result listModelCopyJobs(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listModelCopyJobsAsync(array $args = [])
 * @method \Aws\Result listModelCustomizationJobs(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listModelCustomizationJobsAsync(array $args = [])
 * @method \Aws\Result listModelImportJobs(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listModelImportJobsAsync(array $args = [])
 * @method \Aws\Result listModelInvocationJobs(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listModelInvocationJobsAsync(array $args = [])
 * @method \Aws\Result listPromptRouters(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPromptRoutersAsync(array $args = [])
 * @method \Aws\Result listProvisionedModelThroughputs(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listProvisionedModelThroughputsAsync(array $args = [])
 * @method \Aws\Result listTagsForResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTagsForResourceAsync(array $args = [])
 * @method \Aws\Result putEnforcedGuardrailConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise putEnforcedGuardrailConfigurationAsync(array $args = [])
 * @method \Aws\Result putModelInvocationLoggingConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise putModelInvocationLoggingConfigurationAsync(array $args = [])
 * @method \Aws\Result putResourcePolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise putResourcePolicyAsync(array $args = [])
 * @method \Aws\Result putUseCaseForModelAccess(array $args = [])
 * @method \GuzzleHttp\Promise\Promise putUseCaseForModelAccessAsync(array $args = [])
 * @method \Aws\Result registerMarketplaceModelEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise registerMarketplaceModelEndpointAsync(array $args = [])
 * @method \Aws\Result startAutomatedReasoningPolicyBuildWorkflow(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startAutomatedReasoningPolicyBuildWorkflowAsync(array $args = [])
 * @method \Aws\Result startAutomatedReasoningPolicyTestWorkflow(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startAutomatedReasoningPolicyTestWorkflowAsync(array $args = [])
 * @method \Aws\Result stopEvaluationJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise stopEvaluationJobAsync(array $args = [])
 * @method \Aws\Result stopModelCustomizationJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise stopModelCustomizationJobAsync(array $args = [])
 * @method \Aws\Result stopModelInvocationJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise stopModelInvocationJobAsync(array $args = [])
 * @method \Aws\Result tagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise tagResourceAsync(array $args = [])
 * @method \Aws\Result untagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise untagResourceAsync(array $args = [])
 * @method \Aws\Result updateAutomatedReasoningPolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateAutomatedReasoningPolicyAsync(array $args = [])
 * @method \Aws\Result updateAutomatedReasoningPolicyAnnotations(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateAutomatedReasoningPolicyAnnotationsAsync(array $args = [])
 * @method \Aws\Result updateAutomatedReasoningPolicyTestCase(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateAutomatedReasoningPolicyTestCaseAsync(array $args = [])
 * @method \Aws\Result updateCustomModelDeployment(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateCustomModelDeploymentAsync(array $args = [])
 * @method \Aws\Result updateGuardrail(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateGuardrailAsync(array $args = [])
 * @method \Aws\Result updateMarketplaceModelEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateMarketplaceModelEndpointAsync(array $args = [])
 * @method \Aws\Result updateProvisionedModelThroughput(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateProvisionedModelThroughputAsync(array $args = [])
 */
class BedrockClient extends AwsClient {}
