<?php
namespace Aws\BedrockRuntime\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Bedrock Runtime** service.
 */
class BedrockRuntimeException extends AwsException {}
