<?php
// This file was auto-generated from sdk-root/src/data/grafana/2020-08-18/paginators-1.json
return [ 'pagination' => [ 'ListPermissions' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'permissions', ], 'ListVersions' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'grafanaVersions', ], 'ListWorkspaceServiceAccountTokens' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'serviceAccountTokens', ], 'ListWorkspaceServiceAccounts' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'serviceAccounts', ], 'ListWorkspaces' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'workspaces', ], ],];
