<?php
namespace Aws\DocDBElastic\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon DocumentDB Elastic Clusters** service.
 */
class DocDBElasticException extends AwsException {}
