<?php
namespace Aws\OpenSearchService\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon OpenSearch Service** service.
 */
class OpenSearchServiceException extends AwsException {}
