<?php
namespace Aws\AuditManager\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Audit Manager** service.
 */
class AuditManagerException extends AwsException {}
