<?php
namespace Aws\WellArchitected\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Well-Architected Tool** service.
 */
class WellArchitectedException extends AwsException {}
