<!DOCTYPE html>
<html><head><meta charset="utf-8"><title>{{ $message->title }}</title></head>
<body style="margin:0;padding:0;background:#09090b;font-family:Inter,system-ui,sans-serif;color:#f3f4f6">
  <table cellpadding="0" cellspacing="0" border="0" width="100%" style="padding:24px 0">
    <tr><td align="center">
      <table cellpadding="0" cellspacing="0" border="0" width="600" style="max-width:600px;background:#0f1115;border:1px solid #1f242c;border-radius:6px;overflow:hidden">
        <tr><td style="padding:0">
          <div style="height:6px;background:{{ $color }}"></div>
        </td></tr>
        <tr><td style="padding:24px">
          <div style="font-family:'JetBrains Mono',ui-monospace,monospace;font-size:11px;color:#8a92a0;letter-spacing:1px;margin-bottom:8px">
            HOSTSEBA AI PORTAL · {{ strtoupper($message->severity) }}
          </div>
          <h1 style="margin:0 0 16px 0;color:#f3f4f6;font-size:20px;font-weight:600;line-height:1.3">
            {{ $message->title }}
          </h1>
          <div style="color:#c5cad3;font-size:14px;line-height:1.6;white-space:pre-wrap">{{ $message->body }}</div>
          @if ($message->url)
            <div style="margin-top:24px">
              <a href="{{ $message->url }}"
                 style="display:inline-block;padding:10px 18px;background:{{ $color }};color:#003164;text-decoration:none;font-weight:600;border-radius:4px;font-size:13px">
                Open in portal
              </a>
            </div>
          @endif
        </td></tr>
        <tr><td style="padding:16px 24px;background:#0b0d10;border-top:1px solid #1f242c;color:#5a6473;font-size:11px;font-family:'JetBrains Mono',monospace">
          {{ now()->toDateTimeString() }} · event: {{ $message->event }}
        </td></tr>
      </table>
    </td></tr>
  </table>
</body></html>
