<?php
namespace Aws\SageMaker\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon SageMaker Service** service.
 */
class SageMakerException extends AwsException {}
