<?php
namespace Aws\CloudSearch\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the Amazon CloudSearch service.
 */
class CloudSearchException extends AwsException {}
