<?php
namespace Aws\TaxSettings\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Tax Settings** service.
 */
class TaxSettingsException extends AwsException {}
