<?php
namespace Aws\imagebuilder\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **EC2 Image Builder** service.
 */
class imagebuilderException extends AwsException {}
