<?php
namespace Aws\LicenseManagerLinuxSubscriptions\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS License Manager Linux Subscriptions** service.
 */
class LicenseManagerLinuxSubscriptionsException extends AwsException {}
