<?php
namespace Aws\MigrationHubConfig\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Migration Hub Config** service.
 */
class MigrationHubConfigException extends AwsException {}
