<?php
namespace Aws\Route53Resolver\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Route 53 Resolver** service.
 */
class Route53ResolverException extends AwsException {}
