<?php
namespace Aws\ObservabilityAdmin;

use Aws\AwsClient;

/**
 * This client is used to interact with the **CloudWatch Observability Admin Service** service.
 * @method \Aws\Result createCentralizationRuleForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createCentralizationRuleForOrganizationAsync(array $args = [])
 * @method \Aws\Result createS3TableIntegration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createS3TableIntegrationAsync(array $args = [])
 * @method \Aws\Result createTelemetryPipeline(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createTelemetryPipelineAsync(array $args = [])
 * @method \Aws\Result createTelemetryRule(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createTelemetryRuleAsync(array $args = [])
 * @method \Aws\Result createTelemetryRuleForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createTelemetryRuleForOrganizationAsync(array $args = [])
 * @method \Aws\Result deleteCentralizationRuleForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteCentralizationRuleForOrganizationAsync(array $args = [])
 * @method \Aws\Result deleteS3TableIntegration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteS3TableIntegrationAsync(array $args = [])
 * @method \Aws\Result deleteTelemetryPipeline(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteTelemetryPipelineAsync(array $args = [])
 * @method \Aws\Result deleteTelemetryRule(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteTelemetryRuleAsync(array $args = [])
 * @method \Aws\Result deleteTelemetryRuleForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteTelemetryRuleForOrganizationAsync(array $args = [])
 * @method \Aws\Result getCentralizationRuleForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getCentralizationRuleForOrganizationAsync(array $args = [])
 * @method \Aws\Result getS3TableIntegration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getS3TableIntegrationAsync(array $args = [])
 * @method \Aws\Result getTelemetryEnrichmentStatus(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getTelemetryEnrichmentStatusAsync(array $args = [])
 * @method \Aws\Result getTelemetryEvaluationStatus(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getTelemetryEvaluationStatusAsync(array $args = [])
 * @method \Aws\Result getTelemetryEvaluationStatusForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getTelemetryEvaluationStatusForOrganizationAsync(array $args = [])
 * @method \Aws\Result getTelemetryPipeline(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getTelemetryPipelineAsync(array $args = [])
 * @method \Aws\Result getTelemetryRule(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getTelemetryRuleAsync(array $args = [])
 * @method \Aws\Result getTelemetryRuleForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getTelemetryRuleForOrganizationAsync(array $args = [])
 * @method \Aws\Result listCentralizationRulesForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listCentralizationRulesForOrganizationAsync(array $args = [])
 * @method \Aws\Result listResourceTelemetry(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listResourceTelemetryAsync(array $args = [])
 * @method \Aws\Result listResourceTelemetryForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listResourceTelemetryForOrganizationAsync(array $args = [])
 * @method \Aws\Result listS3TableIntegrations(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listS3TableIntegrationsAsync(array $args = [])
 * @method \Aws\Result listTagsForResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTagsForResourceAsync(array $args = [])
 * @method \Aws\Result listTelemetryPipelines(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTelemetryPipelinesAsync(array $args = [])
 * @method \Aws\Result listTelemetryRules(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTelemetryRulesAsync(array $args = [])
 * @method \Aws\Result listTelemetryRulesForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTelemetryRulesForOrganizationAsync(array $args = [])
 * @method \Aws\Result startTelemetryEnrichment(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startTelemetryEnrichmentAsync(array $args = [])
 * @method \Aws\Result startTelemetryEvaluation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startTelemetryEvaluationAsync(array $args = [])
 * @method \Aws\Result startTelemetryEvaluationForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startTelemetryEvaluationForOrganizationAsync(array $args = [])
 * @method \Aws\Result stopTelemetryEnrichment(array $args = [])
 * @method \GuzzleHttp\Promise\Promise stopTelemetryEnrichmentAsync(array $args = [])
 * @method \Aws\Result stopTelemetryEvaluation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise stopTelemetryEvaluationAsync(array $args = [])
 * @method \Aws\Result stopTelemetryEvaluationForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise stopTelemetryEvaluationForOrganizationAsync(array $args = [])
 * @method \Aws\Result tagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise tagResourceAsync(array $args = [])
 * @method \Aws\Result testTelemetryPipeline(array $args = [])
 * @method \GuzzleHttp\Promise\Promise testTelemetryPipelineAsync(array $args = [])
 * @method \Aws\Result untagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise untagResourceAsync(array $args = [])
 * @method \Aws\Result updateCentralizationRuleForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateCentralizationRuleForOrganizationAsync(array $args = [])
 * @method \Aws\Result updateTelemetryPipeline(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateTelemetryPipelineAsync(array $args = [])
 * @method \Aws\Result updateTelemetryRule(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateTelemetryRuleAsync(array $args = [])
 * @method \Aws\Result updateTelemetryRuleForOrganization(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateTelemetryRuleForOrganizationAsync(array $args = [])
 * @method \Aws\Result validateTelemetryPipelineConfiguration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise validateTelemetryPipelineConfigurationAsync(array $args = [])
 */
class ObservabilityAdminClient extends AwsClient {}
