<?php
namespace Aws\Firehose\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Kinesis Firehose** service.
 */
class FirehoseException extends AwsException {}
