<?php
namespace Aws\Interconnect\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Interconnect** service.
 */
class InterconnectException extends AwsException {}
