<?php
namespace Aws\SocialMessaging\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS End User Messaging Social** service.
 */
class SocialMessagingException extends AwsException {}
