<?php
namespace Aws\GlobalAccelerator\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Global Accelerator** service.
 */
class GlobalAcceleratorException extends AwsException {}
