<?php
// This file was auto-generated from sdk-root/src/data/connecthealth/2025-01-29/paginators-1.json
return [ 'pagination' => [ 'ListDomains' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'domains', ], 'ListSubscriptions' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'subscriptions', ], ],];
