<?php
namespace Aws\ControlTower\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Control Tower** service.
 */
class ControlTowerException extends AwsException {}
