<?php
namespace Aws\SecurityAgent;

use Aws\AwsClient;

/**
 * This client is used to interact with the **AWS Security Agent** service.
 * @method \Aws\Result addArtifact(array $args = [])
 * @method \GuzzleHttp\Promise\Promise addArtifactAsync(array $args = [])
 * @method \Aws\Result batchDeletePentests(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchDeletePentestsAsync(array $args = [])
 * @method \Aws\Result batchGetAgentSpaces(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchGetAgentSpacesAsync(array $args = [])
 * @method \Aws\Result batchGetArtifactMetadata(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchGetArtifactMetadataAsync(array $args = [])
 * @method \Aws\Result batchGetFindings(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchGetFindingsAsync(array $args = [])
 * @method \Aws\Result batchGetPentestJobTasks(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchGetPentestJobTasksAsync(array $args = [])
 * @method \Aws\Result batchGetPentestJobs(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchGetPentestJobsAsync(array $args = [])
 * @method \Aws\Result batchGetPentests(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchGetPentestsAsync(array $args = [])
 * @method \Aws\Result batchGetTargetDomains(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchGetTargetDomainsAsync(array $args = [])
 * @method \Aws\Result createAgentSpace(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createAgentSpaceAsync(array $args = [])
 * @method \Aws\Result createApplication(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createApplicationAsync(array $args = [])
 * @method \Aws\Result createIntegration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createIntegrationAsync(array $args = [])
 * @method \Aws\Result createMembership(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createMembershipAsync(array $args = [])
 * @method \Aws\Result createPentest(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createPentestAsync(array $args = [])
 * @method \Aws\Result createTargetDomain(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createTargetDomainAsync(array $args = [])
 * @method \Aws\Result deleteAgentSpace(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteAgentSpaceAsync(array $args = [])
 * @method \Aws\Result deleteApplication(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteApplicationAsync(array $args = [])
 * @method \Aws\Result deleteArtifact(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteArtifactAsync(array $args = [])
 * @method \Aws\Result deleteIntegration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteIntegrationAsync(array $args = [])
 * @method \Aws\Result deleteMembership(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteMembershipAsync(array $args = [])
 * @method \Aws\Result deleteTargetDomain(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteTargetDomainAsync(array $args = [])
 * @method \Aws\Result getApplication(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getApplicationAsync(array $args = [])
 * @method \Aws\Result getArtifact(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getArtifactAsync(array $args = [])
 * @method \Aws\Result getIntegration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getIntegrationAsync(array $args = [])
 * @method \Aws\Result initiateProviderRegistration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise initiateProviderRegistrationAsync(array $args = [])
 * @method \Aws\Result listAgentSpaces(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listAgentSpacesAsync(array $args = [])
 * @method \Aws\Result listApplications(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listApplicationsAsync(array $args = [])
 * @method \Aws\Result listArtifacts(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listArtifactsAsync(array $args = [])
 * @method \Aws\Result listDiscoveredEndpoints(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listDiscoveredEndpointsAsync(array $args = [])
 * @method \Aws\Result listFindings(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listFindingsAsync(array $args = [])
 * @method \Aws\Result listIntegratedResources(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listIntegratedResourcesAsync(array $args = [])
 * @method \Aws\Result listIntegrations(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listIntegrationsAsync(array $args = [])
 * @method \Aws\Result listMemberships(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listMembershipsAsync(array $args = [])
 * @method \Aws\Result listPentestJobTasks(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPentestJobTasksAsync(array $args = [])
 * @method \Aws\Result listPentestJobsForPentest(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPentestJobsForPentestAsync(array $args = [])
 * @method \Aws\Result listPentests(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPentestsAsync(array $args = [])
 * @method \Aws\Result listTagsForResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTagsForResourceAsync(array $args = [])
 * @method \Aws\Result listTargetDomains(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTargetDomainsAsync(array $args = [])
 * @method \Aws\Result startCodeRemediation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startCodeRemediationAsync(array $args = [])
 * @method \Aws\Result startPentestJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startPentestJobAsync(array $args = [])
 * @method \Aws\Result stopPentestJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise stopPentestJobAsync(array $args = [])
 * @method \Aws\Result tagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise tagResourceAsync(array $args = [])
 * @method \Aws\Result untagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise untagResourceAsync(array $args = [])
 * @method \Aws\Result updateAgentSpace(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateAgentSpaceAsync(array $args = [])
 * @method \Aws\Result updateApplication(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateApplicationAsync(array $args = [])
 * @method \Aws\Result updateFinding(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateFindingAsync(array $args = [])
 * @method \Aws\Result updateIntegratedResources(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateIntegratedResourcesAsync(array $args = [])
 * @method \Aws\Result updatePentest(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updatePentestAsync(array $args = [])
 * @method \Aws\Result updateTargetDomain(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateTargetDomainAsync(array $args = [])
 * @method \Aws\Result verifyTargetDomain(array $args = [])
 * @method \GuzzleHttp\Promise\Promise verifyTargetDomainAsync(array $args = [])
 */
class SecurityAgentClient extends AwsClient {}
