<?php
namespace Aws\PartnerCentralChannel\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Partner Central Channel API** service.
 */
class PartnerCentralChannelException extends AwsException {}
