<?php

namespace Faker\Provider\de_AT;

class Internet extends \Faker\Provider\Internet
{
    protected static $freeEmailDomain = ['aon.at', 'chello.at', 'gmail.com', 'gmx.at', 'univie.ac.at'];
    protected static $tld = ['at', 'co.at', 'com', 'net', 'org'];
}
