<?php
// This file was auto-generated from sdk-root/src/data/acm/2015-12-08/paginators-1.json
return [ 'pagination' => [ 'ListCertificates' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxItems', 'result_key' => 'CertificateSummaryList', ], 'SearchCertificates' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'Results', ], ],];
