<?php
namespace Aws\CloudFront\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the Amazon CloudFront service.
 */
class CloudFrontException extends AwsException {}
