<?php
namespace Aws\Scheduler\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon EventBridge Scheduler** service.
 */
class SchedulerException extends AwsException {}
