<?php
namespace Aws\ManagedGrafana\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Managed Grafana** service.
 */
class ManagedGrafanaException extends AwsException {}
