<?php
// This file was auto-generated from sdk-root/src/data/s3outposts/2017-07-25/paginators-1.json
return [ 'pagination' => [ 'ListEndpoints' => [ 'input_token' => 'NextToken', 'limit_key' => 'MaxResults', 'output_token' => 'NextToken', 'result_key' => 'Endpoints', ], 'ListOutpostsWithS3' => [ 'input_token' => 'NextToken', 'limit_key' => 'MaxResults', 'output_token' => 'NextToken', 'result_key' => 'Outposts', ], 'ListSharedEndpoints' => [ 'input_token' => 'NextToken', 'limit_key' => 'MaxResults', 'output_token' => 'NextToken', 'result_key' => 'Endpoints', ], ],];
