<?php
namespace Aws\IoTEvents\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS IoT Events** service.
 */
class IoTEventsException extends AwsException {}
