<?php
namespace Aws\BackupSearch\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Backup Search** service.
 */
class BackupSearchException extends AwsException {}
