<?php
namespace Aws\CustomerProfiles\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Connect Customer Profiles** service.
 */
class CustomerProfilesException extends AwsException {}
