<?php
namespace Aws\ConnectWisdomService\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Connect Wisdom Service** service.
 */
class ConnectWisdomServiceException extends AwsException {}
