<?php
namespace App\Models;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class BlacklistCheck extends Model
{
    use HasFactory;
    public $timestamps = false;
    protected $fillable = ['server_id', 'ip', 'checked_at', 'list_name', 'is_listed', 'reason'];
    protected $casts = ['checked_at' => 'datetime', 'is_listed' => 'boolean'];
    public function server(): BelongsTo { return $this->belongsTo(Server::class); }
}
