<?php
namespace Aws\NetworkManager\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Network Manager** service.
 */
class NetworkManagerException extends AwsException {}
