<?php

/*
 * This file is part of fruitcake/php-cors
 *
 * (c) Barryvdh <barryvdh@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Fruitcake\Cors\Exceptions;

class InvalidOptionException extends \RuntimeException
{
}
