<?php
namespace Aws\BedrockAgent\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Agents for Amazon Bedrock** service.
 */
class BedrockAgentException extends AwsException {}
