<?php
// This file was auto-generated from sdk-root/src/data/marketplace-agreement/2020-03-01/paginators-1.json
return [ 'pagination' => [ 'GetAgreementEntitlements' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'agreementEntitlements', ], 'GetAgreementTerms' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'acceptedTerms', ], 'ListAgreementCancellationRequests' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'items', ], 'ListAgreementCharges' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'items', ], 'ListAgreementInvoiceLineItems' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'agreementInvoiceLineItemGroupSummaries', ], 'ListAgreementPaymentRequests' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'items', ], 'ListBillingAdjustmentRequests' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'items', ], 'SearchAgreements' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'agreementViewSummaries', ], ],];
