<?php
namespace Aws\BedrockAgentCore;

use Aws\AwsClient;

/**
 * This client is used to interact with the **Amazon Bedrock AgentCore Data Plane Fronting Layer** service.
 * @method \Aws\Result batchCreateMemoryRecords(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchCreateMemoryRecordsAsync(array $args = [])
 * @method \Aws\Result batchDeleteMemoryRecords(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchDeleteMemoryRecordsAsync(array $args = [])
 * @method \Aws\Result batchUpdateMemoryRecords(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchUpdateMemoryRecordsAsync(array $args = [])
 * @method \Aws\Result completeResourceTokenAuth(array $args = [])
 * @method \GuzzleHttp\Promise\Promise completeResourceTokenAuthAsync(array $args = [])
 * @method \Aws\Result createABTest(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createABTestAsync(array $args = [])
 * @method \Aws\Result createEvent(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createEventAsync(array $args = [])
 * @method \Aws\Result createPaymentInstrument(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createPaymentInstrumentAsync(array $args = [])
 * @method \Aws\Result createPaymentSession(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createPaymentSessionAsync(array $args = [])
 * @method \Aws\Result deleteABTest(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteABTestAsync(array $args = [])
 * @method \Aws\Result deleteBatchEvaluation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteBatchEvaluationAsync(array $args = [])
 * @method \Aws\Result deleteEvent(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteEventAsync(array $args = [])
 * @method \Aws\Result deleteMemoryRecord(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteMemoryRecordAsync(array $args = [])
 * @method \Aws\Result deletePaymentInstrument(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deletePaymentInstrumentAsync(array $args = [])
 * @method \Aws\Result deletePaymentSession(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deletePaymentSessionAsync(array $args = [])
 * @method \Aws\Result deleteRecommendation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteRecommendationAsync(array $args = [])
 * @method \Aws\Result evaluate(array $args = [])
 * @method \GuzzleHttp\Promise\Promise evaluateAsync(array $args = [])
 * @method \Aws\Result getABTest(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getABTestAsync(array $args = [])
 * @method \Aws\Result getAgentCard(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getAgentCardAsync(array $args = [])
 * @method \Aws\Result getBatchEvaluation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getBatchEvaluationAsync(array $args = [])
 * @method \Aws\Result getBrowserSession(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getBrowserSessionAsync(array $args = [])
 * @method \Aws\Result getCodeInterpreterSession(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getCodeInterpreterSessionAsync(array $args = [])
 * @method \Aws\Result getEvent(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getEventAsync(array $args = [])
 * @method \Aws\Result getMemoryRecord(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getMemoryRecordAsync(array $args = [])
 * @method \Aws\Result getPaymentInstrument(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getPaymentInstrumentAsync(array $args = [])
 * @method \Aws\Result getPaymentInstrumentBalance(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getPaymentInstrumentBalanceAsync(array $args = [])
 * @method \Aws\Result getPaymentSession(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getPaymentSessionAsync(array $args = [])
 * @method \Aws\Result getRecommendation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getRecommendationAsync(array $args = [])
 * @method \Aws\Result getResourceApiKey(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getResourceApiKeyAsync(array $args = [])
 * @method \Aws\Result getResourceOauth2Token(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getResourceOauth2TokenAsync(array $args = [])
 * @method \Aws\Result getResourcePaymentToken(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getResourcePaymentTokenAsync(array $args = [])
 * @method \Aws\Result getWorkloadAccessToken(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getWorkloadAccessTokenAsync(array $args = [])
 * @method \Aws\Result getWorkloadAccessTokenForJWT(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getWorkloadAccessTokenForJWTAsync(array $args = [])
 * @method \Aws\Result getWorkloadAccessTokenForUserId(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getWorkloadAccessTokenForUserIdAsync(array $args = [])
 * @method \Aws\Result invokeAgentRuntime(array $args = [])
 * @method \GuzzleHttp\Promise\Promise invokeAgentRuntimeAsync(array $args = [])
 * @method \Aws\Result invokeAgentRuntimeCommand(array $args = [])
 * @method \GuzzleHttp\Promise\Promise invokeAgentRuntimeCommandAsync(array $args = [])
 * @method \Aws\Result invokeBrowser(array $args = [])
 * @method \GuzzleHttp\Promise\Promise invokeBrowserAsync(array $args = [])
 * @method \Aws\Result invokeCodeInterpreter(array $args = [])
 * @method \GuzzleHttp\Promise\Promise invokeCodeInterpreterAsync(array $args = [])
 * @method \Aws\Result invokeHarness(array $args = [])
 * @method \GuzzleHttp\Promise\Promise invokeHarnessAsync(array $args = [])
 * @method \Aws\Result listABTests(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listABTestsAsync(array $args = [])
 * @method \Aws\Result listActors(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listActorsAsync(array $args = [])
 * @method \Aws\Result listBatchEvaluations(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listBatchEvaluationsAsync(array $args = [])
 * @method \Aws\Result listBrowserSessions(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listBrowserSessionsAsync(array $args = [])
 * @method \Aws\Result listCodeInterpreterSessions(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listCodeInterpreterSessionsAsync(array $args = [])
 * @method \Aws\Result listEvents(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listEventsAsync(array $args = [])
 * @method \Aws\Result listMemoryExtractionJobs(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listMemoryExtractionJobsAsync(array $args = [])
 * @method \Aws\Result listMemoryRecords(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listMemoryRecordsAsync(array $args = [])
 * @method \Aws\Result listPaymentInstruments(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPaymentInstrumentsAsync(array $args = [])
 * @method \Aws\Result listPaymentSessions(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPaymentSessionsAsync(array $args = [])
 * @method \Aws\Result listRecommendations(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listRecommendationsAsync(array $args = [])
 * @method \Aws\Result listSessions(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listSessionsAsync(array $args = [])
 * @method \Aws\Result processPayment(array $args = [])
 * @method \GuzzleHttp\Promise\Promise processPaymentAsync(array $args = [])
 * @method \Aws\Result retrieveMemoryRecords(array $args = [])
 * @method \GuzzleHttp\Promise\Promise retrieveMemoryRecordsAsync(array $args = [])
 * @method \Aws\Result saveBrowserSessionProfile(array $args = [])
 * @method \GuzzleHttp\Promise\Promise saveBrowserSessionProfileAsync(array $args = [])
 * @method \Aws\Result searchRegistryRecords(array $args = [])
 * @method \GuzzleHttp\Promise\Promise searchRegistryRecordsAsync(array $args = [])
 * @method \Aws\Result startBatchEvaluation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startBatchEvaluationAsync(array $args = [])
 * @method \Aws\Result startBrowserSession(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startBrowserSessionAsync(array $args = [])
 * @method \Aws\Result startCodeInterpreterSession(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startCodeInterpreterSessionAsync(array $args = [])
 * @method \Aws\Result startMemoryExtractionJob(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startMemoryExtractionJobAsync(array $args = [])
 * @method \Aws\Result startRecommendation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startRecommendationAsync(array $args = [])
 * @method \Aws\Result stopBatchEvaluation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise stopBatchEvaluationAsync(array $args = [])
 * @method \Aws\Result stopBrowserSession(array $args = [])
 * @method \GuzzleHttp\Promise\Promise stopBrowserSessionAsync(array $args = [])
 * @method \Aws\Result stopCodeInterpreterSession(array $args = [])
 * @method \GuzzleHttp\Promise\Promise stopCodeInterpreterSessionAsync(array $args = [])
 * @method \Aws\Result stopRuntimeSession(array $args = [])
 * @method \GuzzleHttp\Promise\Promise stopRuntimeSessionAsync(array $args = [])
 * @method \Aws\Result updateABTest(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateABTestAsync(array $args = [])
 * @method \Aws\Result updateBrowserStream(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateBrowserStreamAsync(array $args = [])
 */
class BedrockAgentCoreClient extends AwsClient {}
