<?php
namespace Aws\Sfn;

use Aws\AwsClient;

/**
 * This client is used to interact with the **AWS Step Functions** service.
 * @method \Aws\Result createActivity(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createActivityAsync(array $args = [])
 * @method \Aws\Result createStateMachine(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createStateMachineAsync(array $args = [])
 * @method \Aws\Result createStateMachineAlias(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createStateMachineAliasAsync(array $args = [])
 * @method \Aws\Result deleteActivity(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteActivityAsync(array $args = [])
 * @method \Aws\Result deleteStateMachine(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteStateMachineAsync(array $args = [])
 * @method \Aws\Result deleteStateMachineAlias(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteStateMachineAliasAsync(array $args = [])
 * @method \Aws\Result deleteStateMachineVersion(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteStateMachineVersionAsync(array $args = [])
 * @method \Aws\Result describeActivity(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeActivityAsync(array $args = [])
 * @method \Aws\Result describeExecution(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeExecutionAsync(array $args = [])
 * @method \Aws\Result describeMapRun(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeMapRunAsync(array $args = [])
 * @method \Aws\Result describeStateMachine(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeStateMachineAsync(array $args = [])
 * @method \Aws\Result describeStateMachineAlias(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeStateMachineAliasAsync(array $args = [])
 * @method \Aws\Result describeStateMachineForExecution(array $args = [])
 * @method \GuzzleHttp\Promise\Promise describeStateMachineForExecutionAsync(array $args = [])
 * @method \Aws\Result getActivityTask(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getActivityTaskAsync(array $args = [])
 * @method \Aws\Result getExecutionHistory(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getExecutionHistoryAsync(array $args = [])
 * @method \Aws\Result listActivities(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listActivitiesAsync(array $args = [])
 * @method \Aws\Result listExecutions(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listExecutionsAsync(array $args = [])
 * @method \Aws\Result listMapRuns(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listMapRunsAsync(array $args = [])
 * @method \Aws\Result listStateMachineAliases(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listStateMachineAliasesAsync(array $args = [])
 * @method \Aws\Result listStateMachineVersions(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listStateMachineVersionsAsync(array $args = [])
 * @method \Aws\Result listStateMachines(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listStateMachinesAsync(array $args = [])
 * @method \Aws\Result listTagsForResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTagsForResourceAsync(array $args = [])
 * @method \Aws\Result publishStateMachineVersion(array $args = [])
 * @method \GuzzleHttp\Promise\Promise publishStateMachineVersionAsync(array $args = [])
 * @method \Aws\Result redriveExecution(array $args = [])
 * @method \GuzzleHttp\Promise\Promise redriveExecutionAsync(array $args = [])
 * @method \Aws\Result sendTaskFailure(array $args = [])
 * @method \GuzzleHttp\Promise\Promise sendTaskFailureAsync(array $args = [])
 * @method \Aws\Result sendTaskHeartbeat(array $args = [])
 * @method \GuzzleHttp\Promise\Promise sendTaskHeartbeatAsync(array $args = [])
 * @method \Aws\Result sendTaskSuccess(array $args = [])
 * @method \GuzzleHttp\Promise\Promise sendTaskSuccessAsync(array $args = [])
 * @method \Aws\Result startExecution(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startExecutionAsync(array $args = [])
 * @method \Aws\Result startSyncExecution(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startSyncExecutionAsync(array $args = [])
 * @method \Aws\Result stopExecution(array $args = [])
 * @method \GuzzleHttp\Promise\Promise stopExecutionAsync(array $args = [])
 * @method \Aws\Result tagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise tagResourceAsync(array $args = [])
 * @method \Aws\Result testState(array $args = [])
 * @method \GuzzleHttp\Promise\Promise testStateAsync(array $args = [])
 * @method \Aws\Result untagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise untagResourceAsync(array $args = [])
 * @method \Aws\Result updateMapRun(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateMapRunAsync(array $args = [])
 * @method \Aws\Result updateStateMachine(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateStateMachineAsync(array $args = [])
 * @method \Aws\Result updateStateMachineAlias(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateStateMachineAliasAsync(array $args = [])
 * @method \Aws\Result validateStateMachineDefinition(array $args = [])
 * @method \GuzzleHttp\Promise\Promise validateStateMachineDefinitionAsync(array $args = [])
 */
class SfnClient extends AwsClient {}
