<?php
// This file was auto-generated from sdk-root/src/data/servicecatalog-appregistry/2020-06-24/paginators-1.json
return [ 'pagination' => [ 'ListApplications' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'applications', ], 'ListAssociatedAttributeGroups' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'attributeGroups', ], 'ListAssociatedResources' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'resources', ], 'ListAttributeGroups' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'attributeGroups', ], 'ListAttributeGroupsForApplication' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'attributeGroupsDetails', ], ],];
