<?php
namespace Aws\AugmentedAIRuntime\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Augmented AI Runtime** service.
 */
class AugmentedAIRuntimeException extends AwsException {}
