<?php
namespace Aws\DLM\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Data Lifecycle Manager** service.
 */
class DLMException extends AwsException {}
