<?php
namespace Aws\SupplyChain\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Supply Chain** service.
 */
class SupplyChainException extends AwsException {}
