<?php
namespace Aws\Route53RecoveryReadiness\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Route53 Recovery Readiness** service.
 */
class Route53RecoveryReadinessException extends AwsException {}
