<?php
namespace Aws\ApiGatewayV2\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AmazonApiGatewayV2** service.
 */
class ApiGatewayV2Exception extends AwsException {}
