<?php
namespace Aws\BCMRecommendedActions;

use Aws\AwsClient;

/**
 * This client is used to interact with the **AWS Billing and Cost Management Recommended Actions** service.
 * @method \Aws\Result listRecommendedActions(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listRecommendedActionsAsync(array $args = [])
 */
class BCMRecommendedActionsClient extends AwsClient {}
