<?php
namespace Aws\OpenSearchServerless\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **OpenSearch Service Serverless** service.
 */
class OpenSearchServerlessException extends AwsException {}
