<?php
namespace Aws\PaymentCryptography\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Payment Cryptography Control Plane** service.
 */
class PaymentCryptographyException extends AwsException {}
