<?php
namespace Aws\FMS\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Firewall Management Service** service.
 */
class FMSException extends AwsException {}
