<?php
namespace Aws\WorkspacesInstances\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Workspaces Instances** service.
 */
class WorkspacesInstancesException extends AwsException {}
