<?php
namespace Aws\Signin;

use Aws\AwsClient;

/**
 * This client is used to interact with the **AWS Sign-In Service** service.
 * @method \Aws\Result createOAuth2Token(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createOAuth2TokenAsync(array $args = [])
 */
class SigninClient extends AwsClient {}
