<?php
namespace Aws\BedrockAgentCoreControl;

use Aws\AwsClient;

/**
 * This client is used to interact with the **Amazon Bedrock Agent Core Control Plane Fronting Layer** service.
 * @method \Aws\Result createAgentRuntime(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createAgentRuntimeAsync(array $args = [])
 * @method \Aws\Result createAgentRuntimeEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createAgentRuntimeEndpointAsync(array $args = [])
 * @method \Aws\Result createApiKeyCredentialProvider(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createApiKeyCredentialProviderAsync(array $args = [])
 * @method \Aws\Result createBrowser(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createBrowserAsync(array $args = [])
 * @method \Aws\Result createBrowserProfile(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createBrowserProfileAsync(array $args = [])
 * @method \Aws\Result createCodeInterpreter(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createCodeInterpreterAsync(array $args = [])
 * @method \Aws\Result createConfigurationBundle(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createConfigurationBundleAsync(array $args = [])
 * @method \Aws\Result createEvaluator(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createEvaluatorAsync(array $args = [])
 * @method \Aws\Result createGateway(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createGatewayAsync(array $args = [])
 * @method \Aws\Result createGatewayRule(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createGatewayRuleAsync(array $args = [])
 * @method \Aws\Result createGatewayTarget(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createGatewayTargetAsync(array $args = [])
 * @method \Aws\Result createHarness(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createHarnessAsync(array $args = [])
 * @method \Aws\Result createMemory(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createMemoryAsync(array $args = [])
 * @method \Aws\Result createOauth2CredentialProvider(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createOauth2CredentialProviderAsync(array $args = [])
 * @method \Aws\Result createOnlineEvaluationConfig(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createOnlineEvaluationConfigAsync(array $args = [])
 * @method \Aws\Result createPaymentConnector(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createPaymentConnectorAsync(array $args = [])
 * @method \Aws\Result createPaymentCredentialProvider(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createPaymentCredentialProviderAsync(array $args = [])
 * @method \Aws\Result createPaymentManager(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createPaymentManagerAsync(array $args = [])
 * @method \Aws\Result createPolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createPolicyAsync(array $args = [])
 * @method \Aws\Result createPolicyEngine(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createPolicyEngineAsync(array $args = [])
 * @method \Aws\Result createRegistry(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createRegistryAsync(array $args = [])
 * @method \Aws\Result createRegistryRecord(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createRegistryRecordAsync(array $args = [])
 * @method \Aws\Result createWorkloadIdentity(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createWorkloadIdentityAsync(array $args = [])
 * @method \Aws\Result deleteAgentRuntime(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteAgentRuntimeAsync(array $args = [])
 * @method \Aws\Result deleteAgentRuntimeEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteAgentRuntimeEndpointAsync(array $args = [])
 * @method \Aws\Result deleteApiKeyCredentialProvider(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteApiKeyCredentialProviderAsync(array $args = [])
 * @method \Aws\Result deleteBrowser(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteBrowserAsync(array $args = [])
 * @method \Aws\Result deleteBrowserProfile(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteBrowserProfileAsync(array $args = [])
 * @method \Aws\Result deleteCodeInterpreter(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteCodeInterpreterAsync(array $args = [])
 * @method \Aws\Result deleteConfigurationBundle(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteConfigurationBundleAsync(array $args = [])
 * @method \Aws\Result deleteEvaluator(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteEvaluatorAsync(array $args = [])
 * @method \Aws\Result deleteGateway(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteGatewayAsync(array $args = [])
 * @method \Aws\Result deleteGatewayRule(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteGatewayRuleAsync(array $args = [])
 * @method \Aws\Result deleteGatewayTarget(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteGatewayTargetAsync(array $args = [])
 * @method \Aws\Result deleteHarness(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteHarnessAsync(array $args = [])
 * @method \Aws\Result deleteMemory(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteMemoryAsync(array $args = [])
 * @method \Aws\Result deleteOauth2CredentialProvider(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteOauth2CredentialProviderAsync(array $args = [])
 * @method \Aws\Result deleteOnlineEvaluationConfig(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteOnlineEvaluationConfigAsync(array $args = [])
 * @method \Aws\Result deletePaymentConnector(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deletePaymentConnectorAsync(array $args = [])
 * @method \Aws\Result deletePaymentCredentialProvider(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deletePaymentCredentialProviderAsync(array $args = [])
 * @method \Aws\Result deletePaymentManager(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deletePaymentManagerAsync(array $args = [])
 * @method \Aws\Result deletePolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deletePolicyAsync(array $args = [])
 * @method \Aws\Result deletePolicyEngine(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deletePolicyEngineAsync(array $args = [])
 * @method \Aws\Result deleteRegistry(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteRegistryAsync(array $args = [])
 * @method \Aws\Result deleteRegistryRecord(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteRegistryRecordAsync(array $args = [])
 * @method \Aws\Result deleteResourcePolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteResourcePolicyAsync(array $args = [])
 * @method \Aws\Result deleteWorkloadIdentity(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteWorkloadIdentityAsync(array $args = [])
 * @method \Aws\Result getAgentRuntime(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getAgentRuntimeAsync(array $args = [])
 * @method \Aws\Result getAgentRuntimeEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getAgentRuntimeEndpointAsync(array $args = [])
 * @method \Aws\Result getApiKeyCredentialProvider(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getApiKeyCredentialProviderAsync(array $args = [])
 * @method \Aws\Result getBrowser(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getBrowserAsync(array $args = [])
 * @method \Aws\Result getBrowserProfile(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getBrowserProfileAsync(array $args = [])
 * @method \Aws\Result getCodeInterpreter(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getCodeInterpreterAsync(array $args = [])
 * @method \Aws\Result getConfigurationBundle(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getConfigurationBundleAsync(array $args = [])
 * @method \Aws\Result getConfigurationBundleVersion(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getConfigurationBundleVersionAsync(array $args = [])
 * @method \Aws\Result getEvaluator(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getEvaluatorAsync(array $args = [])
 * @method \Aws\Result getGateway(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getGatewayAsync(array $args = [])
 * @method \Aws\Result getGatewayRule(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getGatewayRuleAsync(array $args = [])
 * @method \Aws\Result getGatewayTarget(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getGatewayTargetAsync(array $args = [])
 * @method \Aws\Result getHarness(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getHarnessAsync(array $args = [])
 * @method \Aws\Result getMemory(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getMemoryAsync(array $args = [])
 * @method \Aws\Result getOauth2CredentialProvider(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getOauth2CredentialProviderAsync(array $args = [])
 * @method \Aws\Result getOnlineEvaluationConfig(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getOnlineEvaluationConfigAsync(array $args = [])
 * @method \Aws\Result getPaymentConnector(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getPaymentConnectorAsync(array $args = [])
 * @method \Aws\Result getPaymentCredentialProvider(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getPaymentCredentialProviderAsync(array $args = [])
 * @method \Aws\Result getPaymentManager(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getPaymentManagerAsync(array $args = [])
 * @method \Aws\Result getPolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getPolicyAsync(array $args = [])
 * @method \Aws\Result getPolicyEngine(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getPolicyEngineAsync(array $args = [])
 * @method \Aws\Result getPolicyGeneration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getPolicyGenerationAsync(array $args = [])
 * @method \Aws\Result getRegistry(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getRegistryAsync(array $args = [])
 * @method \Aws\Result getRegistryRecord(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getRegistryRecordAsync(array $args = [])
 * @method \Aws\Result getResourcePolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getResourcePolicyAsync(array $args = [])
 * @method \Aws\Result getTokenVault(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getTokenVaultAsync(array $args = [])
 * @method \Aws\Result getWorkloadIdentity(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getWorkloadIdentityAsync(array $args = [])
 * @method \Aws\Result listAgentRuntimeEndpoints(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listAgentRuntimeEndpointsAsync(array $args = [])
 * @method \Aws\Result listAgentRuntimeVersions(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listAgentRuntimeVersionsAsync(array $args = [])
 * @method \Aws\Result listAgentRuntimes(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listAgentRuntimesAsync(array $args = [])
 * @method \Aws\Result listApiKeyCredentialProviders(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listApiKeyCredentialProvidersAsync(array $args = [])
 * @method \Aws\Result listBrowserProfiles(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listBrowserProfilesAsync(array $args = [])
 * @method \Aws\Result listBrowsers(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listBrowsersAsync(array $args = [])
 * @method \Aws\Result listCodeInterpreters(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listCodeInterpretersAsync(array $args = [])
 * @method \Aws\Result listConfigurationBundleVersions(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listConfigurationBundleVersionsAsync(array $args = [])
 * @method \Aws\Result listConfigurationBundles(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listConfigurationBundlesAsync(array $args = [])
 * @method \Aws\Result listEvaluators(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listEvaluatorsAsync(array $args = [])
 * @method \Aws\Result listGatewayRules(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listGatewayRulesAsync(array $args = [])
 * @method \Aws\Result listGatewayTargets(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listGatewayTargetsAsync(array $args = [])
 * @method \Aws\Result listGateways(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listGatewaysAsync(array $args = [])
 * @method \Aws\Result listHarnesses(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listHarnessesAsync(array $args = [])
 * @method \Aws\Result listMemories(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listMemoriesAsync(array $args = [])
 * @method \Aws\Result listOauth2CredentialProviders(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listOauth2CredentialProvidersAsync(array $args = [])
 * @method \Aws\Result listOnlineEvaluationConfigs(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listOnlineEvaluationConfigsAsync(array $args = [])
 * @method \Aws\Result listPaymentConnectors(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPaymentConnectorsAsync(array $args = [])
 * @method \Aws\Result listPaymentCredentialProviders(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPaymentCredentialProvidersAsync(array $args = [])
 * @method \Aws\Result listPaymentManagers(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPaymentManagersAsync(array $args = [])
 * @method \Aws\Result listPolicies(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPoliciesAsync(array $args = [])
 * @method \Aws\Result listPolicyEngines(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPolicyEnginesAsync(array $args = [])
 * @method \Aws\Result listPolicyGenerationAssets(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPolicyGenerationAssetsAsync(array $args = [])
 * @method \Aws\Result listPolicyGenerations(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPolicyGenerationsAsync(array $args = [])
 * @method \Aws\Result listRegistries(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listRegistriesAsync(array $args = [])
 * @method \Aws\Result listRegistryRecords(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listRegistryRecordsAsync(array $args = [])
 * @method \Aws\Result listTagsForResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTagsForResourceAsync(array $args = [])
 * @method \Aws\Result listWorkloadIdentities(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listWorkloadIdentitiesAsync(array $args = [])
 * @method \Aws\Result putResourcePolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise putResourcePolicyAsync(array $args = [])
 * @method \Aws\Result setTokenVaultCMK(array $args = [])
 * @method \GuzzleHttp\Promise\Promise setTokenVaultCMKAsync(array $args = [])
 * @method \Aws\Result startPolicyGeneration(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startPolicyGenerationAsync(array $args = [])
 * @method \Aws\Result submitRegistryRecordForApproval(array $args = [])
 * @method \GuzzleHttp\Promise\Promise submitRegistryRecordForApprovalAsync(array $args = [])
 * @method \Aws\Result synchronizeGatewayTargets(array $args = [])
 * @method \GuzzleHttp\Promise\Promise synchronizeGatewayTargetsAsync(array $args = [])
 * @method \Aws\Result tagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise tagResourceAsync(array $args = [])
 * @method \Aws\Result untagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise untagResourceAsync(array $args = [])
 * @method \Aws\Result updateAgentRuntime(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateAgentRuntimeAsync(array $args = [])
 * @method \Aws\Result updateAgentRuntimeEndpoint(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateAgentRuntimeEndpointAsync(array $args = [])
 * @method \Aws\Result updateApiKeyCredentialProvider(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateApiKeyCredentialProviderAsync(array $args = [])
 * @method \Aws\Result updateConfigurationBundle(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateConfigurationBundleAsync(array $args = [])
 * @method \Aws\Result updateEvaluator(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateEvaluatorAsync(array $args = [])
 * @method \Aws\Result updateGateway(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateGatewayAsync(array $args = [])
 * @method \Aws\Result updateGatewayRule(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateGatewayRuleAsync(array $args = [])
 * @method \Aws\Result updateGatewayTarget(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateGatewayTargetAsync(array $args = [])
 * @method \Aws\Result updateHarness(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateHarnessAsync(array $args = [])
 * @method \Aws\Result updateMemory(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateMemoryAsync(array $args = [])
 * @method \Aws\Result updateOauth2CredentialProvider(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateOauth2CredentialProviderAsync(array $args = [])
 * @method \Aws\Result updateOnlineEvaluationConfig(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateOnlineEvaluationConfigAsync(array $args = [])
 * @method \Aws\Result updatePaymentConnector(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updatePaymentConnectorAsync(array $args = [])
 * @method \Aws\Result updatePaymentCredentialProvider(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updatePaymentCredentialProviderAsync(array $args = [])
 * @method \Aws\Result updatePaymentManager(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updatePaymentManagerAsync(array $args = [])
 * @method \Aws\Result updatePolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updatePolicyAsync(array $args = [])
 * @method \Aws\Result updatePolicyEngine(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updatePolicyEngineAsync(array $args = [])
 * @method \Aws\Result updateRegistry(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateRegistryAsync(array $args = [])
 * @method \Aws\Result updateRegistryRecord(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateRegistryRecordAsync(array $args = [])
 * @method \Aws\Result updateRegistryRecordStatus(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateRegistryRecordStatusAsync(array $args = [])
 * @method \Aws\Result updateWorkloadIdentity(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateWorkloadIdentityAsync(array $args = [])
 */
class BedrockAgentCoreControlClient extends AwsClient {}
