<?php
// This file was auto-generated from sdk-root/src/data/bedrock/2023-04-20/paginators-1.json
return [ 'pagination' => [ 'ListAutomatedReasoningPolicies' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'automatedReasoningPolicySummaries', ], 'ListAutomatedReasoningPolicyBuildWorkflows' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'automatedReasoningPolicyBuildWorkflowSummaries', ], 'ListAutomatedReasoningPolicyTestCases' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'testCases', ], 'ListAutomatedReasoningPolicyTestResults' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'testResults', ], 'ListCustomModelDeployments' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'modelDeploymentSummaries', ], 'ListCustomModels' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'modelSummaries', ], 'ListEnforcedGuardrailsConfiguration' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'result_key' => 'guardrailsConfig', ], 'ListEvaluationJobs' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'jobSummaries', ], 'ListGuardrails' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'guardrails', ], 'ListImportedModels' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'modelSummaries', ], 'ListInferenceProfiles' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'inferenceProfileSummaries', ], 'ListMarketplaceModelEndpoints' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'marketplaceModelEndpoints', ], 'ListModelCopyJobs' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'modelCopyJobSummaries', ], 'ListModelCustomizationJobs' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'modelCustomizationJobSummaries', ], 'ListModelImportJobs' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'modelImportJobSummaries', ], 'ListModelInvocationJobs' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'invocationJobSummaries', ], 'ListPromptRouters' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'promptRouterSummaries', ], 'ListProvisionedModelThroughputs' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'provisionedModelSummaries', ], ],];
