<?php
namespace Aws\Notifications\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS User Notifications** service.
 */
class NotificationsException extends AwsException {}
