<?php
namespace Aws\IoTSecureTunneling\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS IoT Secure Tunneling** service.
 */
class IoTSecureTunnelingException extends AwsException {}
