<?php
namespace Aws\Route53Profiles\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Route 53 Profiles** service.
 */
class Route53ProfilesException extends AwsException {}
