<?php
namespace Aws\BCMDataExports\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Billing and Cost Management Data Exports** service.
 */
class BCMDataExportsException extends AwsException {}
