<?php
namespace Aws\PartnerCentralAccount;

use Aws\AwsClient;

/**
 * This client is used to interact with the **Partner Central Account API** service.
 * @method \Aws\Result acceptConnectionInvitation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise acceptConnectionInvitationAsync(array $args = [])
 * @method \Aws\Result associateAwsTrainingCertificationEmailDomain(array $args = [])
 * @method \GuzzleHttp\Promise\Promise associateAwsTrainingCertificationEmailDomainAsync(array $args = [])
 * @method \Aws\Result cancelConnection(array $args = [])
 * @method \GuzzleHttp\Promise\Promise cancelConnectionAsync(array $args = [])
 * @method \Aws\Result cancelConnectionInvitation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise cancelConnectionInvitationAsync(array $args = [])
 * @method \Aws\Result cancelProfileUpdateTask(array $args = [])
 * @method \GuzzleHttp\Promise\Promise cancelProfileUpdateTaskAsync(array $args = [])
 * @method \Aws\Result createConnectionInvitation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createConnectionInvitationAsync(array $args = [])
 * @method \Aws\Result createPartner(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createPartnerAsync(array $args = [])
 * @method \Aws\Result disassociateAwsTrainingCertificationEmailDomain(array $args = [])
 * @method \GuzzleHttp\Promise\Promise disassociateAwsTrainingCertificationEmailDomainAsync(array $args = [])
 * @method \Aws\Result getAllianceLeadContact(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getAllianceLeadContactAsync(array $args = [])
 * @method \Aws\Result getConnection(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getConnectionAsync(array $args = [])
 * @method \Aws\Result getConnectionInvitation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getConnectionInvitationAsync(array $args = [])
 * @method \Aws\Result getConnectionPreferences(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getConnectionPreferencesAsync(array $args = [])
 * @method \Aws\Result getPartner(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getPartnerAsync(array $args = [])
 * @method \Aws\Result getProfileUpdateTask(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getProfileUpdateTaskAsync(array $args = [])
 * @method \Aws\Result getProfileVisibility(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getProfileVisibilityAsync(array $args = [])
 * @method \Aws\Result getVerification(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getVerificationAsync(array $args = [])
 * @method \Aws\Result listConnectionInvitations(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listConnectionInvitationsAsync(array $args = [])
 * @method \Aws\Result listConnections(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listConnectionsAsync(array $args = [])
 * @method \Aws\Result listPartners(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listPartnersAsync(array $args = [])
 * @method \Aws\Result listTagsForResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTagsForResourceAsync(array $args = [])
 * @method \Aws\Result putAllianceLeadContact(array $args = [])
 * @method \GuzzleHttp\Promise\Promise putAllianceLeadContactAsync(array $args = [])
 * @method \Aws\Result putProfileVisibility(array $args = [])
 * @method \GuzzleHttp\Promise\Promise putProfileVisibilityAsync(array $args = [])
 * @method \Aws\Result rejectConnectionInvitation(array $args = [])
 * @method \GuzzleHttp\Promise\Promise rejectConnectionInvitationAsync(array $args = [])
 * @method \Aws\Result sendEmailVerificationCode(array $args = [])
 * @method \GuzzleHttp\Promise\Promise sendEmailVerificationCodeAsync(array $args = [])
 * @method \Aws\Result startProfileUpdateTask(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startProfileUpdateTaskAsync(array $args = [])
 * @method \Aws\Result startVerification(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startVerificationAsync(array $args = [])
 * @method \Aws\Result tagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise tagResourceAsync(array $args = [])
 * @method \Aws\Result untagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise untagResourceAsync(array $args = [])
 * @method \Aws\Result updateConnectionPreferences(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateConnectionPreferencesAsync(array $args = [])
 */
class PartnerCentralAccountClient extends AwsClient {}
