<?php
namespace Aws\CognitoIdentity\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the Amazon Cognito Identity Logs service.
 */
class CognitoIdentityException extends AwsException {}
