<?php
namespace Aws\NotificationsContacts\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS User Notifications Contacts** service.
 */
class NotificationsContactsException extends AwsException {}
