<?php
namespace Aws\KinesisVideoMedia;

use Aws\AwsClient;

/**
 * This client is used to interact with the **Amazon Kinesis Video Streams Media** service.
 * @method \Aws\Result getMedia(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getMediaAsync(array $args = [])
 */
class KinesisVideoMediaClient extends AwsClient {}
