<?php
namespace Aws\PrometheusService\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Prometheus Service** service.
 */
class PrometheusServiceException extends AwsException {}
