<?php
namespace Aws\WorkSpacesThinClient\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon WorkSpaces Thin Client** service.
 */
class WorkSpacesThinClientException extends AwsException {}
