<?php
namespace Aws\AppConfig\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon AppConfig** service.
 */
class AppConfigException extends AwsException {}
