<?php
namespace Aws\CloudControlApi\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Cloud Control API** service.
 */
class CloudControlApiException extends AwsException {}
