<?php
namespace Aws\WorkDocs\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon WorkDocs** service.
 */
class WorkDocsException extends AwsException {}
