<?php
namespace Aws\XRay;

use Aws\AwsClient;

/**
 * This client is used to interact with the **AWS X-Ray** service.
 * @method \Aws\Result batchGetTraces(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchGetTracesAsync(array $args = [])
 * @method \Aws\Result cancelTraceRetrieval(array $args = [])
 * @method \GuzzleHttp\Promise\Promise cancelTraceRetrievalAsync(array $args = [])
 * @method \Aws\Result createGroup(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createGroupAsync(array $args = [])
 * @method \Aws\Result createSamplingRule(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createSamplingRuleAsync(array $args = [])
 * @method \Aws\Result deleteGroup(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteGroupAsync(array $args = [])
 * @method \Aws\Result deleteResourcePolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteResourcePolicyAsync(array $args = [])
 * @method \Aws\Result deleteSamplingRule(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteSamplingRuleAsync(array $args = [])
 * @method \Aws\Result getEncryptionConfig(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getEncryptionConfigAsync(array $args = [])
 * @method \Aws\Result getGroup(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getGroupAsync(array $args = [])
 * @method \Aws\Result getGroups(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getGroupsAsync(array $args = [])
 * @method \Aws\Result getIndexingRules(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getIndexingRulesAsync(array $args = [])
 * @method \Aws\Result getInsight(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getInsightAsync(array $args = [])
 * @method \Aws\Result getInsightEvents(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getInsightEventsAsync(array $args = [])
 * @method \Aws\Result getInsightImpactGraph(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getInsightImpactGraphAsync(array $args = [])
 * @method \Aws\Result getInsightSummaries(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getInsightSummariesAsync(array $args = [])
 * @method \Aws\Result getRetrievedTracesGraph(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getRetrievedTracesGraphAsync(array $args = [])
 * @method \Aws\Result getSamplingRules(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getSamplingRulesAsync(array $args = [])
 * @method \Aws\Result getSamplingStatisticSummaries(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getSamplingStatisticSummariesAsync(array $args = [])
 * @method \Aws\Result getSamplingTargets(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getSamplingTargetsAsync(array $args = [])
 * @method \Aws\Result getServiceGraph(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getServiceGraphAsync(array $args = [])
 * @method \Aws\Result getTimeSeriesServiceStatistics(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getTimeSeriesServiceStatisticsAsync(array $args = [])
 * @method \Aws\Result getTraceGraph(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getTraceGraphAsync(array $args = [])
 * @method \Aws\Result getTraceSegmentDestination(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getTraceSegmentDestinationAsync(array $args = [])
 * @method \Aws\Result getTraceSummaries(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getTraceSummariesAsync(array $args = [])
 * @method \Aws\Result listResourcePolicies(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listResourcePoliciesAsync(array $args = [])
 * @method \Aws\Result listRetrievedTraces(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listRetrievedTracesAsync(array $args = [])
 * @method \Aws\Result listTagsForResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listTagsForResourceAsync(array $args = [])
 * @method \Aws\Result putEncryptionConfig(array $args = [])
 * @method \GuzzleHttp\Promise\Promise putEncryptionConfigAsync(array $args = [])
 * @method \Aws\Result putResourcePolicy(array $args = [])
 * @method \GuzzleHttp\Promise\Promise putResourcePolicyAsync(array $args = [])
 * @method \Aws\Result putTelemetryRecords(array $args = [])
 * @method \GuzzleHttp\Promise\Promise putTelemetryRecordsAsync(array $args = [])
 * @method \Aws\Result putTraceSegments(array $args = [])
 * @method \GuzzleHttp\Promise\Promise putTraceSegmentsAsync(array $args = [])
 * @method \Aws\Result startTraceRetrieval(array $args = [])
 * @method \GuzzleHttp\Promise\Promise startTraceRetrievalAsync(array $args = [])
 * @method \Aws\Result tagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise tagResourceAsync(array $args = [])
 * @method \Aws\Result untagResource(array $args = [])
 * @method \GuzzleHttp\Promise\Promise untagResourceAsync(array $args = [])
 * @method \Aws\Result updateGroup(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateGroupAsync(array $args = [])
 * @method \Aws\Result updateIndexingRule(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateIndexingRuleAsync(array $args = [])
 * @method \Aws\Result updateSamplingRule(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateSamplingRuleAsync(array $args = [])
 * @method \Aws\Result updateTraceSegmentDestination(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateTraceSegmentDestinationAsync(array $args = [])
 */
class XRayClient extends AwsClient {}
