<?php
namespace Aws\ElasticLoadBalancing\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the Elastic Load Balancing service.
 */
class ElasticLoadBalancingException extends AwsException {}
