<?php
namespace Aws\Wickr;

use Aws\AwsClient;

/**
 * This client is used to interact with the **AWS Wickr Admin API** service.
 * @method \Aws\Result batchCreateUser(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchCreateUserAsync(array $args = [])
 * @method \Aws\Result batchDeleteUser(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchDeleteUserAsync(array $args = [])
 * @method \Aws\Result batchLookupUserUname(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchLookupUserUnameAsync(array $args = [])
 * @method \Aws\Result batchReinviteUser(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchReinviteUserAsync(array $args = [])
 * @method \Aws\Result batchResetDevicesForUser(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchResetDevicesForUserAsync(array $args = [])
 * @method \Aws\Result batchToggleUserSuspendStatus(array $args = [])
 * @method \GuzzleHttp\Promise\Promise batchToggleUserSuspendStatusAsync(array $args = [])
 * @method \Aws\Result createBot(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createBotAsync(array $args = [])
 * @method \Aws\Result createDataRetentionBot(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createDataRetentionBotAsync(array $args = [])
 * @method \Aws\Result createDataRetentionBotChallenge(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createDataRetentionBotChallengeAsync(array $args = [])
 * @method \Aws\Result createNetwork(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createNetworkAsync(array $args = [])
 * @method \Aws\Result createSecurityGroup(array $args = [])
 * @method \GuzzleHttp\Promise\Promise createSecurityGroupAsync(array $args = [])
 * @method \Aws\Result deleteBot(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteBotAsync(array $args = [])
 * @method \Aws\Result deleteDataRetentionBot(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteDataRetentionBotAsync(array $args = [])
 * @method \Aws\Result deleteNetwork(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteNetworkAsync(array $args = [])
 * @method \Aws\Result deleteSecurityGroup(array $args = [])
 * @method \GuzzleHttp\Promise\Promise deleteSecurityGroupAsync(array $args = [])
 * @method \Aws\Result getBot(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getBotAsync(array $args = [])
 * @method \Aws\Result getBotsCount(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getBotsCountAsync(array $args = [])
 * @method \Aws\Result getDataRetentionBot(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getDataRetentionBotAsync(array $args = [])
 * @method \Aws\Result getGuestUserHistoryCount(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getGuestUserHistoryCountAsync(array $args = [])
 * @method \Aws\Result getNetwork(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getNetworkAsync(array $args = [])
 * @method \Aws\Result getNetworkSettings(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getNetworkSettingsAsync(array $args = [])
 * @method \Aws\Result getOidcInfo(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getOidcInfoAsync(array $args = [])
 * @method \Aws\Result getOpentdfConfig(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getOpentdfConfigAsync(array $args = [])
 * @method \Aws\Result getSecurityGroup(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getSecurityGroupAsync(array $args = [])
 * @method \Aws\Result getUser(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getUserAsync(array $args = [])
 * @method \Aws\Result getUsersCount(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getUsersCountAsync(array $args = [])
 * @method \Aws\Result listBlockedGuestUsers(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listBlockedGuestUsersAsync(array $args = [])
 * @method \Aws\Result listBots(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listBotsAsync(array $args = [])
 * @method \Aws\Result listDevicesForUser(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listDevicesForUserAsync(array $args = [])
 * @method \Aws\Result listGuestUsers(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listGuestUsersAsync(array $args = [])
 * @method \Aws\Result listNetworks(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listNetworksAsync(array $args = [])
 * @method \Aws\Result listSecurityGroupUsers(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listSecurityGroupUsersAsync(array $args = [])
 * @method \Aws\Result listSecurityGroups(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listSecurityGroupsAsync(array $args = [])
 * @method \Aws\Result listUsers(array $args = [])
 * @method \GuzzleHttp\Promise\Promise listUsersAsync(array $args = [])
 * @method \Aws\Result registerOidcConfig(array $args = [])
 * @method \GuzzleHttp\Promise\Promise registerOidcConfigAsync(array $args = [])
 * @method \Aws\Result registerOidcConfigTest(array $args = [])
 * @method \GuzzleHttp\Promise\Promise registerOidcConfigTestAsync(array $args = [])
 * @method \Aws\Result registerOpentdfConfig(array $args = [])
 * @method \GuzzleHttp\Promise\Promise registerOpentdfConfigAsync(array $args = [])
 * @method \Aws\Result updateBot(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateBotAsync(array $args = [])
 * @method \Aws\Result updateDataRetention(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateDataRetentionAsync(array $args = [])
 * @method \Aws\Result updateGuestUser(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateGuestUserAsync(array $args = [])
 * @method \Aws\Result updateNetwork(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateNetworkAsync(array $args = [])
 * @method \Aws\Result updateNetworkSettings(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateNetworkSettingsAsync(array $args = [])
 * @method \Aws\Result updateSecurityGroup(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateSecurityGroupAsync(array $args = [])
 * @method \Aws\Result updateUser(array $args = [])
 * @method \GuzzleHttp\Promise\Promise updateUserAsync(array $args = [])
 */
class WickrClient extends AwsClient {}
