<?php
namespace Aws\ResourceExplorer2\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Resource Explorer** service.
 */
class ResourceExplorer2Exception extends AwsException {}
