<?php
namespace Aws\Signin\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Sign-In Service** service.
 */
class SigninException extends AwsException {}
