<?php
namespace Aws\Invoicing\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Invoicing** service.
 */
class InvoicingException extends AwsException {}
