<?php
// This file was auto-generated from sdk-root/src/data/launch-wizard/2018-05-10/paginators-1.json
return [ 'pagination' => [ 'ListDeploymentEvents' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'deploymentEvents', ], 'ListDeploymentPatternVersions' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'deploymentPatternVersions', ], 'ListDeployments' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'deployments', ], 'ListWorkloadDeploymentPatterns' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'workloadDeploymentPatterns', ], 'ListWorkloads' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'workloads', ], ],];
