<?php
namespace Aws\KinesisVideoWebRTCStorage\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Kinesis Video WebRTC Storage** service.
 */
class KinesisVideoWebRTCStorageException extends AwsException {}
