<?php
namespace Aws\Wickr\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Wickr Admin API** service.
 */
class WickrException extends AwsException {}
