<?php
namespace Aws\Inspector\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Inspector** service.
 */
class InspectorException extends AwsException {}
