<?php
namespace Aws\CodeGuruProfiler\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon CodeGuru Profiler** service.
 */
class CodeGuruProfilerException extends AwsException {}
